==> create-url-0.3.1.tgz: package/lib/index.esm.js <==
/**
 * @module-suite/create-url v0.3.0
 * Author: Gabe M <hey@gabe.mx>
 *
 * https://github.com/zelzen/module-suite
 */

import { normalize } from 'path';
import qs from 'qs';
import semver from 'semver';

/**
 * Creates an import url for Module Server
 *
 * @param moduleName - Name of module (npm package name)
 * @param moduleVersion - Version of module. Can be a SEMVER range.
 * @param options - Query and Path options for url
 */
function createUrl(moduleName, moduleVersion, _ref) {
  var filePath = _ref.filePath,
      minify = _ref.minify,
      host = _ref.host,
      output = _ref.output,
      transforms = _ref.transforms;

  if (!host || host.startsWith('http') === false) {
    throw new Error("Expected host to be a valid URL. Received \"" + host + "\"");
  }

  var isValidSemver = semver.valid(moduleVersion) != null || semver.validRange(moduleVersion) != null;

  if (isValidSemver === false) {
    throw new Error("Expected valid semver or range for \"" + moduleName + "\". Received: " + moduleVersion);
  }

  var queryParams = qs.stringify({
    minify: minify,
    output: output,
    // Pass `transforms=false` if an empty Array is specified.
    transforms: transforms != null && transforms.length === 0 ? false : transforms
  }, {
    arrayFormat: 'comma'
  });
  var path = "/" + moduleName + "@" + moduleVersion;
  if (filePath) path += "/" + filePath;
  if (queryParams) path += "?" + queryParams;
  return host + normalize(path);
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

/**
 * Creates an import url for each dependency.
 *
 * @param deps - Dependencies object, normally from package.json
 * @param options - Additional options for `createUrl`
 */
function createDependencyUrls(dependencies, _ref) {
  var _ref$filePaths = _ref.filePaths,
      filePaths = _ref$filePaths === void 0 ? {} : _ref$filePaths,
      options = _objectWithoutPropertiesLoose(_ref, ["filePaths"]);

  // Create import url for each entry
  // Use Object.keys to support IE 11
  return Object.keys(dependencies).reduce(function (accumDeps, moduleName) {
    var moduleVersion = dependencies[moduleName];
    var importDec = createUrl(moduleName, moduleVersion, _extends({}, options, {
      filePath: filePaths[moduleName]
    })); // @ts-ignore

    accumDeps[moduleName] = importDec;
    return accumDeps;
  }, {});
}

export { createDependencyUrls, createUrl };

==> create-url-0.3.2.tgz: package/lib/index.esm.js <==
/**
 * @module-suite/create-url v0.3.1
 * Author: Gabe M <hey@gabe.mx>
 *
 * https://github.com/zelzen/module-suite
 */

import { normalize } from 'path';
import qs from 'qs';
import semver from 'semver';

/**
 * Creates an import url for Module Server
 *
 * @param moduleName - Name of module (npm package name)
 * @param moduleVersion - Version of module. Can be a SEMVER range.
 * @param options - Query and Path options for url
 */
function createUrl(moduleName, moduleVersion, // TODO: Default transforms to true.
// TODO: Default output to source
// TODO: Default minify to true
// TODO: Default filePath to empty string
_ref) {
  var filePath = _ref.filePath,
      minify = _ref.minify,
      host = _ref.host,
      output = _ref.output,
      transforms = _ref.transforms;

  if (!host || host.startsWith('http') === false) {
    throw new Error("Expected host to be a valid URL. Received \"" + host + "\"");
  }

  var isValidSemver = semver.valid(moduleVersion) != null || semver.validRange(moduleVersion) != null;

  if (isValidSemver === false) {
    throw new Error("Expected valid semver or range for \"" + moduleName + "\". Received: " + moduleVersion);
  }

  var queryParams = qs.stringify({
    minify: minify,
    output: output,
    // TODO: Allow transforms: true for transforms
    // Pass `transforms=false` if an empty Array is specified.
    transforms: transforms != null && transforms.length === 0 ? false : transforms
  }, {
    arrayFormat: 'comma'
  });
  var path = "/" + moduleName + "@" + moduleVersion;
  if (filePath) path += "/" + filePath;
  if (queryParams) path += "?" + queryParams;
  return host + normalize(path);
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

/**
 * Creates an import url for each dependency.
 *
 * @param deps - Dependencies object, normally from package.json
 * @param options - Additional options for `createUrl`
 */
function createDependencyUrls(dependencies, _ref) {
  var _ref$filePaths = _ref.filePaths,
      filePaths = _ref$filePaths === void 0 ? {} : _ref$filePaths,
      options = _objectWithoutPropertiesLoose(_ref, ["filePaths"]);

  // Create import url for each entry
  // Use Object.keys to support IE 11
  return Object.keys(dependencies).reduce(function (accumDeps, moduleName) {
    var moduleVersion = dependencies[moduleName];
    var importDec = createUrl(moduleName, moduleVersion, _extends({}, options, {
      filePath: filePaths[moduleName]
    })); // @ts-ignore

    accumDeps[moduleName] = importDec;
    return accumDeps;
  }, {});
}

export { createDependencyUrls, createUrl };
